@@ -27,6 +27,9 @@ pub mod linux;
 /// module containing a progressbar
 pub mod pbar;
 
+/// widgets implementation
+pub mod widget;
+
 pub use linux::Terminal;
 
 pub use ft::{effects, print};
